;
; AutoIt Version: 3.0
; Language:       English
; Platform:       Win9x/NT
; Author:         Michael W. Bayley         
;
; Script Function:
;   Export Bookmarks as HTML Page

#include "TrayUrlDefs.au3"
#include "TrayUrlIniFunc.au3"

;
; Global values
;

; Title Information
$TitleBar = "TrayURL HTMP Exporter Version 2.0, (c) 2007 Michael W. Bayley"

; Program Values
$Tag = ""
$Major = 0
$Minor = 0

; URL Entry Values
$Categories = 0
$Items = 0
$Index = 0
$Index2 = 0
$Cat = ""
$Record = CreateRecord("", "", "", "", 0, "")

; HTML File Values
$HtmlFile = ""
$HtmlHandle = -1

$HtmlHead1 = "<HTML>"
$HtmlHead2 = "<HEAD>"
$HtmlHead3 = "  <TITLE>My Bookmarks</TITLE>"
$HtmlHead4 = "</HEAD>"
$HtmlHead5 = "<BODY BGCOLOR=" & Chr(34) & "#efefef" & Chr(34) & ">"
$HtmlHead6 = "<P>"
$HtmlHead7 = "  <HR>"
$HtmlHead8 = "<P ALIGN=Center>"
$HtmlHead9 = "<B><BIG><BIG><BIG>My Bookmarks</BIG></BIG></BIG></B>"
$HtmlHead10 = "<P ALIGN=Center>"
$HtmlHead11 = "  <HR>"

$HtmlCategory1 = "<P ALIGN=Left>"
$HtmlCategory2 = "<B><BIG><BIG>"
$HtmlCategory3 = "</BIG></BIG></B>"
$HtmlCategory4 = "<br><br>"

$HtmlSpacer = "&nbsp;"
$HtmlSpacer2 = "<P ALIGN=Left><br>"

$HtmlEntry1 = "<A HREF=" & Chr(34)
$HtmlEntry2 = Chr(34) & "><BIG>"
$HtmlEntry3 = "</BIG></A>"
$HtmlEntry4 = "<br>"
;$HtmlEntry4 = "<P ALIGN=Left>"

$HtmlTail1 = "</BODY></HTML>"


;
; Main Code
;
; Entry:       <None>
; Return:      0 - No errors
;              1 - Fatal error encountered
; Procedure:   1. If command line parameter then message & exit.
;              3. Error if ini file not found.
;              3. Verify it is a TrayURL profile, error if not.
;              4, Create the HTML output file.
;              5. Write the title information.
;              6. Export the categories and URL entries.
;              7. Exit all done.
;

; 1. If command line parameter then message & exit.
$msg = "This program will export the TrayURL categories & URLs as a webpage.  The" & @CRLF
$msg = $msg & "intention is to give you access to your bookmarks when you are uusing a system" & @CRLF
$msg = $msg & "that will not let you run programs (like a library).  If you run the program with no" & @CRLF
$msg = $msg & "command line arguments then the default profile will be used, otherwise you can" & @CRLF
$msg = $msg & "specify a single profile on the command line to use that profile." & @CRLF & @CRLF
$msg = $msg & "In all instances the profile file msut exist in the same directory as the program." & @CRLF & @CRLF
MsgBox(0, $TitleBar, $msg)

If $CmdLine[0] > 1 Then
   MsgBox(0, $TitleBar, "Error - Invalid number of command line arguments!")
   Exit(1)
ElseIf $CmdLine[0] == 1 Then
   $IniFile = @ScriptDir
   If StringRight($IniFile, 1) == "\" Then
      $IniFile = $IniFile & $CmdLine[1] & ".ini"
   Else
      $IniFile = $IniFile & "\" & $CmdLine[1] & ".ini"
   EndIf
EndIf


; 2. Error if ini file not found.
If FileExists($IniFile) <> 1 Then
   MsgBox(0, $TitleBar, "Error - Profile " & $IniFile & " not found!")
   Exit(1)   
EndIf


; 3. Verify it is a TrayURL profile, error if not.
$Tag = IniRead($IniFile, $IniProgram, $IniTag, "")
$Major = Number(IniRead($IniFile, $IniProgram, $IniMajor, 0))
$Minor = Number(IniRead($IniFile, $IniProgram, $IniMinor, 0))

If $Tag <> $ProgramID Then
   MsgBox(0, $TitleBar, "Error - Profile " & $IniFile & " does not appear to be valid!")
   Exit(1)   
EndIf

If $Major <> $ProgramMajor OR $Minor <> $ProgramMinor Then
   $msg = "WARNING! The profile appears to be from a different version of TrayURL." & @CRLF
   $msg = $msg & "Proceeding may produce unknown results." & @CRLF & @CRLF
   $msg = $msg & "Proceed anyway?" & @CRLF & @CRLF
   If MsgBox(260, $TitleBar, $msg) <> 6 Then Exit(0)
EndIf


; 4, Create the HTML output file.
$HtmlFile = StringLeft($IniFile, StringLen($IniFile) - 4) & ".html"
If FileExists($HtmlFile) Then
   $msg = "WARNING! The HTML appears to already exist!  Overwrite it?" & @CRLF
   If MsgBox(260, $TitleBar, $msg) <> 6 Then Exit(0)
EndIf

$HtmlHandle = FileOpen($HtmlFile, 2)
If $HtmlHandle == -1 Then
   MsgBox(0, $TitleBar, "Error - Unable to create file " & $HtmlFile & "!")
   Exit(1)
EndIf
   

; 5. Write the title information.
If HtmlWrite($HtmlHandle, $HtmlHead1) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead2) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead3) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead4) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead5) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead6) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead7) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead8) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead9) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead10) Then Exit(1)
If HtmlWrite($HtmlHandle, $HtmlHead11) Then Exit(1)


; 6. Export the categories and URL entries.
$Cat = $IniCatMain
$Items = IniRead($IniFile, $Cat, $IniItems, 0)
If $Items Then
   ; Write the category
   If HtmlWrite($HtmlHandle, $HtmlCategory1) Then Exit(1)
   If HtmlWrite($HtmlHandle, $HtmlCategory2 & $Cat & $HtmlCategory3) Then Exit(1)
   If HtmlWrite($HtmlHandle, $HtmlCategory4) Then Exit(1)
   
   ; Process entries
   For $index2 = 1 To $Items
      ; Read next item
      $Record = ReadRecordByIndex($TitleBar, $Cat, $Index2)
   
      ; Write it out if not blank
      If StringLen($Record[$RECNAME]) AND StringLen($Record[$RECURL]) Then
         If HtmlWrite($HtmlHandle, $HtmlSpacer & $HtmlSpacer & $HtmlSpacer) Then Exit(1)
         If HtmlWrite($HtmlHandle, $HtmlEntry1 & $Record[$RECURL] & $HtmlEntry2 & $Record[$RECNAME] & $HtmlEntry3) Then Exit(1)
         If HtmlWrite($HtmlHandle, $HtmlEntry4) Then Exit(1)
      EndIf
   Next
   
   ; Write out blank space between categories
   If HtmlWrite($HtmlHandle, $HtmlSpacer2) Then Exit(1)
EndIf 

; Process the categories
$Categories = IniRead($IniFile, $IniCatSection, $IniItems, 0)
$Index = 1
While $Index <= $Categories
   $Cat = IniRead($IniFile, $IniCatSection, $IniItem & $Index, "")
   If StringLen($Cat) Then
      $Items = IniRead($IniFile, $Cat, $IniItems, 0)
      If $Items Then
         ; Write the category
         If HtmlWrite($HtmlHandle, $HtmlCategory1) Then Exit(1)
         If HtmlWrite($HtmlHandle, $HtmlCategory2 & $Cat & $HtmlCategory3) Then Exit(1)
         If HtmlWrite($HtmlHandle, $HtmlCategory4) Then Exit(1)
   
         ; Process entries
         For $index2 = 1 To $Items
            ; Read next item
            $Record = ReadRecordByIndex($TitleBar, $Cat, $Index2)
   
            ; Write it out if not blank
            If StringLen($Record[$RECNAME]) AND StringLen($Record[$RECURL]) Then
               If HtmlWrite($HtmlHandle, $HtmlSpacer & $HtmlSpacer & $HtmlSpacer) Then Exit(1)
               If HtmlWrite($HtmlHandle, $HtmlEntry1 & $Record[$RECURL] & $HtmlEntry2 & $Record[$RECNAME] & $HtmlEntry3) Then Exit(1)
               If HtmlWrite($HtmlHandle, $HtmlEntry4) Then Exit(1)
            EndIf
         Next

         ; Write out blank space between categories
         If HtmlWrite($HtmlHandle, $HtmlSpacer2) Then Exit(1)
      EndIf
   EndIf
   $Index = $Index + 1
WEnd

; Write out HTML Trailer.
If HtmlWrite($HtmlHandle, $HtmlTail1) Then Exit(1)

; Close the HTML File
FileClose($HtmlHandle)


; 7. Exit all done.
MsgBox(0, $TitleBar, "Process Complete!")
Exit(0)


;
; User Defined Functions
;

;
; HtmlWrite($handle, $text)
;
; Procedure:   1. Write the line.
;              2. If error then close file & report error.
;              3. Exit all done.
; Inputs:      $handle     HTML file handle
;              $text       Text to write
; Returns:     0 if all ok
;              1 if error
;
Func  HtmlWrite($handle, $text)
   ; 1. Write the line.
   If FileWrite($handle, $text) <> 1 Then
      ; 2. If error then close file & report error.
      FileClose($handle)
      MsgBox(0, $TitleBar, "Error - Failure writing to HTML file.")
      Return(1)
   EndIf
   
   ; 3. Exit all done.
   Return(0)
EndFunc

